# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator 2.3.33.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Model(Model):
    """An Azure Machine Learning Model.

    :param id: The Model Id.
    :type id: str
    :param name: The Model name.
    :type name: str
    :param framework: The Model framework.
    :type framework: str
    :param framework_version: The Model framework version.
    :type framework_version: str
    :param version: The Model version assigned by Model Management Service.
    :type version: long
    :param datasets: The list of datasets associated with the model.
    :type datasets: list[~_restclient.models.DatasetReference]
    :param url: The URL of the Model. Usually a SAS URL.
    :type url: str
    :param mime_type: The MIME type of Model content. For more details about
     MIME type, please open
     https://www.iana.org/assignments/media-types/media-types.xhtml
    :type mime_type: str
    :param description: The Model description text.
    :type description: str
    :param created_time: The Model creation time (UTC).
    :type created_time: datetime
    :param modified_time: The Model last modified time (UTC).
    :type modified_time: datetime
    :param unpack: Indicates whether we need to unpack the Model during docker
     Image creation.
    :type unpack: bool
    :param parent_model_id: The Parent Model Id.
    :type parent_model_id: str
    :param run_id: The RunId that created this model.
    :type run_id: str
    :param experiment_name: The name of the experiment where this model was
     created.
    :type experiment_name: str
    :param kv_tags: The Model tag dictionary. Items are mutable.
    :type kv_tags: dict[str, str]
    :param properties: The Model property dictionary. Properties are
     immutable.
    :type properties: dict[str, str]
    :param derived_model_ids: Models dervied from this model
    :type derived_model_ids: list[str]
    :param sample_input_data: Sample Input Data for the Model. A reference to
     a dataset in the workspace in the format aml://dataset/{datasetId}
    :type sample_input_data: str
    :param sample_output_data: Sample Output Data for the Model. A reference
     to a dataset in the workspace in the format aml://dataset/{datasetId}
    :type sample_output_data: str
    :param resource_requirements: Resource requirements for the model
    :type resource_requirements: ~_restclient.models.ModelResourceRequirements
    :param created_by: The User who created this entity.
    :type created_by: ~_restclient.models.ModelCreatedBy
    """

    _validation = {
        'name': {'required': True},
        'url': {'required': True},
        'mime_type': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'framework': {'key': 'framework', 'type': 'str'},
        'framework_version': {'key': 'frameworkVersion', 'type': 'str'},
        'version': {'key': 'version', 'type': 'long'},
        'datasets': {'key': 'datasets', 'type': '[DatasetReference]'},
        'url': {'key': 'url', 'type': 'str'},
        'mime_type': {'key': 'mimeType', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'created_time': {'key': 'createdTime', 'type': 'iso-8601'},
        'modified_time': {'key': 'modifiedTime', 'type': 'iso-8601'},
        'unpack': {'key': 'unpack', 'type': 'bool'},
        'parent_model_id': {'key': 'parentModelId', 'type': 'str'},
        'run_id': {'key': 'runId', 'type': 'str'},
        'experiment_name': {'key': 'experimentName', 'type': 'str'},
        'kv_tags': {'key': 'kvTags', 'type': '{str}'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'derived_model_ids': {'key': 'derivedModelIds', 'type': '[str]'},
        'sample_input_data': {'key': 'sampleInputData', 'type': 'str'},
        'sample_output_data': {'key': 'sampleOutputData', 'type': 'str'},
        'resource_requirements': {'key': 'resourceRequirements', 'type': 'ModelResourceRequirements'},
        'created_by': {'key': 'createdBy', 'type': 'ModelCreatedBy'},
    }

    def __init__(self, name, url, mime_type, id=None, framework=None, framework_version=None, version=None, datasets=None, description=None, created_time=None, modified_time=None, unpack=None, parent_model_id=None, run_id=None, experiment_name=None, kv_tags=None, properties=None, derived_model_ids=None, sample_input_data=None, sample_output_data=None, resource_requirements=None, created_by=None):
        super(Model, self).__init__()
        self.id = id
        self.name = name
        self.framework = framework
        self.framework_version = framework_version
        self.version = version
        self.datasets = datasets
        self.url = url
        self.mime_type = mime_type
        self.description = description
        self.created_time = created_time
        self.modified_time = modified_time
        self.unpack = unpack
        self.parent_model_id = parent_model_id
        self.run_id = run_id
        self.experiment_name = experiment_name
        self.kv_tags = kv_tags
        self.properties = properties
        self.derived_model_ids = derived_model_ids
        self.sample_input_data = sample_input_data
        self.sample_output_data = sample_output_data
        self.resource_requirements = resource_requirements
        self.created_by = created_by
